@@ -113,7 +113,11 @@ def pack_log(input_args):
                         print(f"file {log_file} is not exist")
 
     # terminal process bar for compress with alive-progress
-    print(f"pack complete, total {len(log_files)} files, output file: {output_file_path}")
+    # show the output file size with MB, precision=2
+    print(f"compress finished, output file: {output_file_path}, size: {os.path.getsize(output_file_path) / 1024 / 1024:.2f} MB")
+
+    print(f"compress finished, total {len(log_files)} files output file: {output_file_path}")
+    print(f"package size: {os.path.getsize(output_file_path) / 1024 / 1024:.2f} MB")
 
     upload_to_obs(output_file_path)
 
